@@ -1,13 +1,15 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-import os
 import sys
 import plac
-from bat import Bat
+from os import path
 
-VIM_PATH = os.path.expanduser('~')+'/.vim/'
-ACTIONS = ['install', 'search', 'remove', 'update']
+from bat import Bat
+from util import console
+
+VIM_PATH = path.join(path.expanduser('~'), '.vim')
+ACTIONS = ['install', 'search', 'remove', 'update', 'browse']
 NOARG_ACTIONS = ['init', 'syncdb', 'remove_all', 'update_all', 'list_installed', 'list_all']
 ACTIONS.extend(NOARG_ACTIONS)
 
@@ -37,50 +39,60 @@ def list_all():
 
 def install(*scripts):
     """install scripts"""
-    if scripts.__len__() >= 1:
-        for index in xrange(0, scripts.__len__()):
+    if len(scripts) >= 1:
+        for index in xrange(0, len(scripts)):
             bat = Bat(scripts[index])
             bat.install()
     else:
-        print('Please use `vimpyre install <script-name>` and try again!')
+        console('Please use `vimpyre install <script-name>` and try again!')
 
 def search(*scripts):
     """search script"""
-    if scripts.__len__() > 1:
-        print('Please search one script name!')
+    if len(scripts) > 1:
+        console('Please search one script name!')
         sys.exit(1)
 
     bat = Bat(scripts[0])
     rets = bat.search()
 
-    print('=> => Send bats to search vim-scripts ...')
+    console('=> => Send bats to search vim-scripts ...')
     if rets:
         for item in rets:
-            if os.path.exists(VIM_PATH + 'vimpyre/%s' % item['name']):
-                print('\033[1m%s\033[m => %s \033[1m[installed]\033[m' % (item['name'].encode('utf-8'), item['description'].encode('utf-8')))
+            if path.isdir(path.join(VIM_PATH, 'vimpyre', item['name'])):
+                console('\033[1m%s\033[m => %s \033[1m[installed]\033[m' % (item['name'].encode('utf-8'), item['description'].encode('utf-8')))
             else:
-                print('\033[1m%s\033[m => %s' % (item['name'].encode('utf-8'), item['description'].encode('utf-8')))
+                console('\033[1m%s\033[m => %s' % (item['name'].encode('utf-8'), item['description'].encode('utf-8')))
     else:
-        print('No such vim-scripts! Please use `vimpyre syncdb` and try again!')
+        console('No such vim-scripts! Please use `vimpyre syncdb` and try again!')
 
 def remove(*scripts):
     """remove scripts"""
-    if scripts.__len__() >= 1:
-        for index in xrange(0, scripts.__len__()):
+    if len(scripts) >= 1:
+        for index in xrange(0, len(scripts)):
             bat = Bat(scripts[index])
             bat.remove()
     else:
-        print('Please use `vimpyre remove <script-name>` and try again!')
+        console('Please use `vimpyre remove <script-name>` and try again!')
 
 
 def update(*scripts):
     """update scripts"""
-    if scripts.__len__() >= 1:
-        for index in xrange(0, scripts.__len__()):
+    if len(scripts) >= 1:
+        for index in xrange(0, len(scripts)):
             bat = Bat(scripts[index])
             bat.update()
     else:
-        print('Please use `vimpyre update <script-name>` and try again!')
+        console('Please use `vimpyre update <script-name>` and try again!')
+
+def browse(*scripts):
+    """browse script's homepage in your web browser"""
+    if len(scripts) >= 1:
+        for index in xrange(0, len(scripts)):
+            bat = Bat(scripts[index])
+            bat.open_homepage()
+    else:
+        console('Please use `vimpyre browse <script-name>` and try again!')
+
 
 @plac.annotations(
     action=', '.join(ACTIONS),
@@ -88,11 +100,11 @@ def update(*scripts):
 def dispatch(action, *scripts):
     """main function"""
     if action not in ACTIONS:
-        print('no such action, exit!')
+        console('no such action, exit!')
         sys.exit(1)
 
     if action not in NOARG_ACTIONS and not scripts:
-        print('Please give a vim script name and try again!')
+        console('Please give a vim script name and try again!')
         sys.exit(1)
     elif action in NOARG_ACTIONS:
         eval(action + '()')
